@@ -68,7 +68,7 @@ class DiagramTreeBuilder:
 
     def instantiate(self, group, tree):
         for stmt in tree.stmts:
-            # Translate Node having group attribute to SubGraph
+            # Translate Node having group attribute to Group
             if isinstance(stmt, parser.Node):
                 group_attr = [a for a in stmt.attrs if a.name == 'group']
                 if group_attr:
@@ -76,7 +76,7 @@ class DiagramTreeBuilder:
                     stmt.attrs.remove(group_id)
 
                     if group_id.value != group.id:
-                        stmt = parser.SubGraph(group_id.value, [stmt])
+                        stmt = parser.Group(group_id.value, [stmt])
 
             # Instantiate statements
             if isinstance(stmt, parser.Node):
@@ -85,42 +85,33 @@ class DiagramTreeBuilder:
                 self.belong_to(node, group)
 
             elif isinstance(stmt, parser.Edge):
-                nodes = stmt.nodes.pop(0)
-                edge_from = [DiagramNode.get(n) for n in nodes]
-                for node in edge_from:
+                from_nodes = [DiagramNode.get(n) for n in stmt.from_nodes]
+                to_nodes = [DiagramNode.get(n) for n in stmt.to_nodes]
+
+                for node in from_nodes + to_nodes:
                     self.belong_to(node, group)
 
-                while len(stmt.nodes):
-                    edge_type, edge_to = stmt.nodes.pop(0)
-                    edge_to = [DiagramNode.get(n) for n in edge_to]
-                    for node in edge_to:
-                        self.belong_to(node, group)
+                for node1 in from_nodes:
+                    for node2 in to_nodes:
+                        edge = DiagramEdge.get(node1, node2)
+                        edge.set_dir(stmt.edge_type)
+                        edge.set_attributes(stmt.attrs)
 
-                    for node1 in edge_from:
-                        for node2 in edge_to:
-                            edge = DiagramEdge.get(node1, node2)
-                            if edge_type:
-                                attrs = [parser.Attr('dir', edge_type)]
-                                edge.set_attributes(attrs)
-                            edge.set_attributes(stmt.attrs)
-
-                    edge_from = edge_to
-
-            elif isinstance(stmt, parser.SubGraph):
+            elif isinstance(stmt, parser.Group):
                 subgroup = NodeGroup.get(stmt.id)
                 subgroup.level = group.level + 1
                 self.belong_to(subgroup, group)
                 self.instantiate(subgroup, stmt)
 
-            elif isinstance(stmt, parser.DefAttrs):
-                group.set_attributes(stmt.attrs)
+            elif isinstance(stmt, parser.Attr):
+                group.set_attribute(stmt)
 
-            elif isinstance(stmt, parser.AttrClass):
-                name = unquote(stmt.name)
-                Diagram.classes[name] = stmt
-
-            elif isinstance(stmt, parser.AttrPlugin):
-                self.diagram.set_plugin(stmt.name, stmt.attrs)
+            elif isinstance(stmt, parser.Extension):
+                if stmt.type == 'class':
+                    name = unquote(stmt.name)
+                    Diagram.classes[name] = stmt
+                elif stmt.type == 'plugin':
+                    self.diagram.set_plugin(stmt.name, stmt.attrs)
 
             elif isinstance(stmt, parser.Statements):
                 self.instantiate(group, stmt)
