@@ -14,6 +14,7 @@
 #  limitations under the License.
 
 import re
+import sys
 import blockdiag
 import blockdiag.builder
 import blockdiag.drawer
@@ -21,11 +22,6 @@ import blockdiag.parser
 from blockdiag.utils.bootstrap import Application, Options
 
 
-# FIXME: for compatibility
-from blockdiag.utils.bootstrap import detectfont
-detectfont
-
-
 class BlockdiagOptions(Options):
     def build_parser(self):
         super(BlockdiagOptions, self).build_parser()
@@ -38,8 +34,8 @@ class BlockdiagOptions(Options):
 class BlockdiagApp(Application):
     module = blockdiag
 
-    def parse_options(self):
-        self.options = BlockdiagOptions(self.module).parse()
+    def parse_options(self, args):
+        self.options = BlockdiagOptions(self.module).parse(args)
 
     def build_diagram(self, tree):
         if not self.options.separate:
@@ -62,5 +58,5 @@ class BlockdiagApp(Application):
             return 0
 
 
-def main():
-    return BlockdiagApp().run()
+def main(args=sys.argv[1:]):
+    return BlockdiagApp().run(args)
