@@ -23,7 +23,7 @@ from blockdiag.imagedraw import base
 from blockdiag.imagedraw.utils import cached
 from blockdiag.utils import urlutil, Box, Size
 from blockdiag.utils.fontmap import parse_fontpath
-from blockdiag.utils.functools import partial
+from blockdiag.utils.compat import string_types
 
 
 class PDFImageDraw(base.ImageDraw):
@@ -34,6 +34,8 @@ class PDFImageDraw(base.ImageDraw):
         self.canvas = None
         self.fonts = {}
 
+        self.set_canvas_size(Size(1, 1))  # This line make textsize() workable
+
     def set_canvas_size(self, size):
         self.canvas = canvas.Canvas(self.filename, pagesize=size)
         self.size = size
@@ -89,7 +91,7 @@ class PDFImageDraw(base.ImageDraw):
             self.canvas.setDash()
 
     def set_stroke_color(self, color="black"):
-        if isinstance(color, basestring):
+        if isinstance(color, string_types):
             self.canvas.setStrokeColor(color)
         elif color:
             rgb = (color[0] / 256.0, color[1] / 256.0, color[2] / 256.0)
@@ -98,7 +100,7 @@ class PDFImageDraw(base.ImageDraw):
             self.set_stroke_color()
 
     def set_fill_color(self, color="white"):
-        if isinstance(color, basestring):
+        if isinstance(color, string_types):
             if color != 'none':
                 self.canvas.setFillColor(color)
         elif color:
@@ -128,6 +130,7 @@ class PDFImageDraw(base.ImageDraw):
 
     @cached
     def textlinesize(self, string, font):
+        self.set_font(font)
         width = self.canvas.stringWidth(string, font.path, font.size)
         return Size(int(math.ceil(width)), font.size)
 
