@@ -14,11 +14,15 @@
 #  limitations under the License.
 
 import re
-import cStringIO
+from blockdiag.utils.compat import u, string_types
+try:
+    from io import StringIO
+except ImportError:
+    from cStringIO import StringIO
 
 
 def _escape(s):
-    if not isinstance(s, (str, unicode)):
+    if not isinstance(s, string_types):
         s = str(s)
     return s.replace("&", "&amp;").replace("<", "&lt;").replace(">", "&gt;")
 
@@ -53,28 +57,26 @@ class base(object):
         clsname = self.__class__.__name__
         indent = '  ' * level
 
-        io.write('%s<%s' % (indent, clsname))
+        io.write(u('%s<%s') % (indent, clsname))
         for key in sorted(self.attributes):
             value = self.attributes[key]
             if value is not None:
-                io.write(' %s=%s' % (_escape(key), _quote(value)))
+                io.write(u(' %s=%s') % (_escape(key), _quote(value)))
 
         if self.elements == []:
             if self.text is not None:
-                text = _escape(self.text).encode('utf-8')
-                io.write(">%s</%s>\n" % (text, clsname))
+                io.write(u(">%s</%s>\n") % (_escape(self.text), clsname))
             else:
-                io.write(" />\n")
+                io.write(u(" />\n"))
         elif self.elements:
             if self.text is not None:
-                text = _escape(self.text).encode('utf-8')
-                io.write(">%s\n" % (text,))
+                io.write(u(">%s\n") % (_escape(self.text),))
             else:
-                io.write(">\n")
+                io.write(u(">\n"))
 
             for e in self.elements:
                 e.to_xml(io, level + 1)
-            io.write('%s</%s>\n' % (indent, clsname))
+            io.write(u('%s</%s>\n') % (indent, clsname))
 
 
 class element(base):
@@ -100,13 +102,13 @@ class svg(base):
         self.add_attribute('xmlns', 'http://www.w3.org/2000/svg')
 
     def to_xml(self):
-        io = cStringIO.StringIO()
+        io = StringIO()
 
         if not self.nodoctype:
             url = "http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd"
-            io.write("<?xml version='1.0' encoding='UTF-8'?>\n")
-            io.write('<!DOCTYPE svg PUBLIC '
-                     '"-//W3C//DTD SVG 1.0//EN" "%s">\n' % url)
+            io.write(u("<?xml version='1.0' encoding='UTF-8'?>\n"))
+            io.write(u('<!DOCTYPE svg PUBLIC ') +
+                     u('"-//W3C//DTD SVG 1.0//EN" "%s">\n') % url)
 
         super(svg, self).to_xml(io)
 
