@@ -120,7 +120,7 @@ class RoundedBox(NodeShape):
                 drawer.path(path, fill=fill, outline=fill)
         elif self.node.background:
             drawer.path(path, fill=self.node.color, outline=self.node.color)
-            drawer.loadImage(self.node.background, self.textbox)
+            drawer.image(self.textbox, self.node.background)
             drawer.path(path, fill="none",
                         outline=self.node.linecolor, style=self.node.style)
         else:
