@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from __future__ import division
 from blockdiag.noderenderer import NodeShape
 from blockdiag.noderenderer import install_renderer
 from blockdiag.utils import Box, XY
@@ -8,8 +9,8 @@ class Square(NodeShape):
     def __init__(self, node, metrics=None):
         super(Square, self).__init__(node, metrics)
 
-        r = min(metrics.node_width, metrics.node_height) / 2 + \
-            metrics.cellsize / 2
+        r = min(metrics.node_width, metrics.node_height) // 2 + \
+            metrics.cellsize // 2
         pt = metrics.cell(node).center
         self.connectors = [XY(pt.x, pt.y - r),  # top
                            XY(pt.x + r, pt.y),  # right
