@@ -46,14 +46,12 @@ from blockdiag.utils.compat import u
 
 ENCODING = 'utf-8'
 
-Graph = namedtuple('Graph', 'type id stmts')
-SubGraph = namedtuple('SubGraph', 'id stmts')
+Diagram = namedtuple('Diagram', 'type id stmts')
+Group = namedtuple('Group', 'id stmts')
 Node = namedtuple('Node', 'id attrs')
 Attr = namedtuple('Attr', 'name value')
-Edge = namedtuple('Edge', 'nodes attrs')
-DefAttrs = namedtuple('DefAttrs', 'object attrs')
-AttrPlugin = namedtuple('AttrPlugin', 'name attrs')
-AttrClass = namedtuple('AttrClass', 'name attrs')
+Edge = namedtuple('Edge', 'from_nodes edge_type to_nodes attrs')
+Extension = namedtuple('Extension', 'type name attrs')
 Statements = namedtuple('Statements', 'stmts')
 
 
@@ -63,134 +61,177 @@ class ParseException(Exception):
 
 def tokenize(string):
     """str -> Sequence(Token)"""
-    specs = [
-        ('Comment', (r'/\*(.|[\r\n])*?\*/', MULTILINE)),
-        ('Comment', (r'(//|#).*',)),
-        ('NL',      (r'[\r\n]+',)),
-        ('Space',   (r'[ \t\r\n]+',)),
-        ('Name',    (u('[A-Za-z_0-9\u0080-\uffff]') +
-                     u('[A-Za-z_\\-.0-9\u0080-\uffff]*'),)),
-        ('Op',      (r'[{};,=\[\]]|(<->)|(<-)|(--)|(->)|(>-<)|(-<)|(>-)',)),
-        ('Number',  (r'-?(\.[0-9]+)|([0-9]+(\.[0-9]*)?)',)),
-        ('String',  (r'(?P<quote>"|\').*?(?<!\\)(?P=quote)', DOTALL)),
+    # flake8: NOQA
+    specs = [                                                                 # NOQA
+        ('Comment', (r'/\*(.|[\r\n])*?\*/', MULTILINE)),                      # NOQA
+        ('Comment', (r'(//|#).*',)),                                          # NOQA
+        ('NL',      (r'[\r\n]+',)),                                           # NOQA
+        ('Space',   (r'[ \t\r\n]+',)),                                        # NOQA
+        ('Name',    (u('[A-Za-z_0-9\u0080-\uffff]') +                         # NOQA
+                     u('[A-Za-z_\\-.0-9\u0080-\uffff]*'),)),                  # NOQA
+        ('Op',      (r'[{};,=\[\]]|(<->)|(<-)|(--)|(->)|(>-<)|(-<)|(>-)',)),  # NOQA
+        ('Number',  (r'-?(\.[0-9]+)|([0-9]+(\.[0-9]*)?)',)),                  # NOQA
+        ('String',  (r'(?P<quote>"|\').*?(?<!\\)(?P=quote)', DOTALL)),        # NOQA
     ]
     useless = ['Comment', 'NL', 'Space']
     t = make_tokenizer(specs)
     return [x for x in t(string) if x.type not in useless]
 
 
+def create_mapper(fn, default_value=None):
+    if default_value is None:
+        return lambda args: fn(*args)
+    else:
+        return lambda args: fn(*args) if args else default_value
+
+
+def flatten(seq):
+    return sum(seq, [])
+
+
+def oneplus_to_list(first, more):
+    return [first] + more
+
+
 def parse(seq):
     """Sequence(Token) -> object"""
-    unarg = lambda f: lambda args: f(*args)
     tokval = lambda x: x.value
-    flatten = lambda list: sum(list, [])
-    node_flatten = lambda l: sum([[l[0]]] + list(l[1:]), [])
-    n = lambda s: a(Token('Name', s)) >> tokval
     op = lambda s: a(Token('Op', s)) >> tokval
     op_ = lambda s: skip(op(s))
-    _id = some(lambda t:
-               t.type in ['Name', 'Number', 'String']).named('id') >> tokval
-    make_nodes = lambda args: Statements([Node(n, args[-1]) for n in args[0]])
-    make_graph_attr = lambda args: DefAttrs('graph', [Attr(*args)])
-    make_edge = lambda x, x2, xs, attrs: Edge([x, x2] + xs, attrs)
+    _id = some(lambda t: t.type in ['Name', 'Number', 'String']) >> tokval
+    keyword = lambda s: a(Token('Name', s)) >> tokval
+
+    def make_node_list(node_list, attrs):
+        return Statements([Node(node, attrs) for node in node_list])
+
+    def make_edge(first, edge_type, second, followers, attrs):
+        edges = [Edge(first, edge_type, second, attrs)]
+
+        from_node = second
+        for edge_type, to_node in followers:
+            edges.append(Edge(from_node, edge_type, to_node, attrs))
+            from_node = to_node
+
+        return Statements(edges)
 
     #
     # parts of syntax
     #
-    node_id = _id  # + maybe(port)
     node_list = (
-        node_id +
-        many(op_(',') + node_id)
-        >> node_flatten)
-    a_list = (
         _id +
-        maybe(op_('=') + _id) +
-        skip(maybe(op(',')))
-        >> unarg(Attr))
-    attr_list = (
-        many(op_('[') + many(a_list) + op_(']'))
-        >> flatten)
-    graph_attr = _id + op_('=') + _id >> make_graph_attr
+        many(op_(',') + _id)
+        >> create_mapper(oneplus_to_list)
+    )
+    option_stmt = (
+        _id +
+        maybe(op_('=') + _id)
+        >> create_mapper(Attr)
+    )
+    option_list = (
+        maybe(op_('[') + option_stmt + many(op_(',') + option_stmt) + op_(']'))
+        >> create_mapper(oneplus_to_list, default_value=[])
+    )
 
-    #  nodes statements::
+    #  node (node list) statement::
     #     A;
     #     B [attr = value, attr = value];
     #     C, D [attr = value, attr = value];
     #
-    multi_node_stmt = node_list + attr_list >> make_nodes
+    node_stmt = (
+        node_list + option_list
+        >> create_mapper(make_node_list)
+    )
 
-    #  edge statements::
+    #  edge statement::
     #     A -> B;
     #     A <- B;
     #
-    edge_rhs = (op('->') | op('--') | op('<-') | op('<->') |
-                op('>-') | op('-<') | op('>-<')) + node_list
+    edge_relation = (
+        op('->') | op('--') | op('<-') | op('<->') |
+        op('>-') | op('-<') | op('>-<')
+    )
     edge_stmt = (
         node_list +
-        edge_rhs +
-        many(edge_rhs) +
-        attr_list
-        >> unarg(make_edge))
+        edge_relation +
+        node_list +
+        many(edge_relation + node_list) +
+        option_list
+        >> create_mapper(make_edge)
+    )
 
-    #  class statements::
-    #     class red [color = red];
+    #  attributes statement::
+    #     default_shape = box;
+    #     default_fontsize = 16;
     #
-    class_stmt = (
-        skip(n('class')) +
-        node_id +
-        attr_list
-        >> unarg(AttrClass))
+    attribute_stmt = (
+        _id + op_('=') + _id
+        >> create_mapper(Attr)
+    )
 
-    #  plugin statements::
+    #  extension statement (class, plugin)::
+    #     class red [color = red];
     #     plugin attributes [name = Name];
     #
-    plugin_stmt = (
-        skip(n('plugin')) +
-        node_id +
-        attr_list
-        >> unarg(AttrPlugin))
+    extension_stmt = (
+        (keyword('class') | keyword('plugin')) +
+        _id +
+        option_list
+        >> create_mapper(Extension)
+    )
 
-    #  group statements::
+    #  group statement::
     #     group {
     #        A;
     #     }
     #
-    group = forward_decl()
-    stmt = (
-        edge_stmt
-        | class_stmt
-        | plugin_stmt
-        | group
-        | graph_attr
-        | multi_node_stmt
+    group_stmt = forward_decl()
+    group_inline_stmt = (
+        edge_stmt |
+        group_stmt |
+        attribute_stmt |
+        node_stmt
     )
-    stmt_list = many(stmt + skip(maybe(op(';'))))
-    group.define(
-        skip(n('group')) +
+    group_inline_stmt_list = (
+        many(group_inline_stmt + skip(maybe(op(';'))))
+    )
+    group_stmt.define(
+        skip(keyword('group')) +
         maybe(_id) +
         op_('{') +
-        stmt_list +
+        group_inline_stmt_list +
         op_('}')
-        >> unarg(SubGraph))
+        >> create_mapper(Group)
+    )
 
     #
-    # graph
+    # diagram statement::
+    #     blockdiag {
+    #        A;
+    #     }
     #
-    graph = (
-        maybe(n('diagram') | n('blockdiag')) +
+    diagram_inline_stmt = (
+        extension_stmt |
+        group_inline_stmt
+    )
+    diagram_inline_stmt_list = (
+        many(diagram_inline_stmt + skip(maybe(op(';'))))
+    )
+    diagram = (
+        maybe(keyword('diagram') | keyword('blockdiag')) +
         maybe(_id) +
         op_('{') +
-        stmt_list +
+        diagram_inline_stmt_list +
         op_('}')
-        >> unarg(Graph))
-    dotfile = graph + skip(finished)
+        >> create_mapper(Diagram)
+    )
+    dotfile = diagram + skip(finished)
 
     return dotfile.parse(seq)
 
 
 def sort_tree(tree):
     def weight(node):
-        if isinstance(node, (Attr, DefAttrs, AttrPlugin, AttrClass)):
+        if isinstance(node, (Attr, Extension)):
             return 1
         else:
             return 2
