@@ -19,17 +19,16 @@ from blockdiag import plugins
 
 class AutoClass(plugins.NodeHandler):
     def on_created(self, node):
-        if node.id:
-            for name, klass in self.diagram.classes.items():
-                pattern1 = "^%s$" % name
-                pattern2 = "\\.%s$" % re.escape(name)
+        if node.id is None:
+            return
 
-                if re.search(pattern1, node.id):
-                    node.set_attributes(klass.attrs)
-                elif re.search(pattern2, node.id):
-                    node.set_attributes(klass.attrs)
-                    node.label = re.sub(pattern2, '', node.id)
+        for name, klass in self.diagram.classes.items():
+            pattern = "_%s$" % re.escape(name)
+
+            if re.search(pattern, node.id):
+                node.label = re.sub(pattern, '', node.id)
+                node.set_attributes(klass.attrs)
 
 
-def setup(self, diagram):
-    plugins.install_node_handler(AutoClass(diagram))
+def setup(self, diagram, **kwargs):
+    plugins.install_node_handler(AutoClass(diagram, **kwargs))
