@@ -8,9 +8,8 @@ else:
 
 import os
 import io
-import tempfile
 from blockdiag.utils.compat import u
-from blockdiag.tests.utils import stderr_wrapper, with_pil
+from blockdiag.tests.utils import capture_stderr, with_pil, TemporaryDirectory
 
 from docutils import nodes
 from docutils.core import publish_doctree, publish_parts
@@ -22,15 +21,17 @@ class TestRstDirectives(unittest.TestCase):
     def setUp(self):
         docutils.register_directive('blockdiag',
                                     directives.BlockdiagDirectiveBase)
-        self.tmpdir = tempfile.mkdtemp()
+        self._tmpdir = TemporaryDirectory()
 
     def tearDown(self):
         if 'blockdiag' in docutils._directives:
             del docutils._directives['blockdiag']
 
-        for filename in os.listdir(self.tmpdir):
-            os.unlink(self.tmpdir + "/" + filename)
-        os.rmdir(self.tmpdir)
+        self._tmpdir.clean()
+
+    @property
+    def tmpdir(self):
+        return self._tmpdir.name
 
     def test_setup(self):
         directives.setup()
@@ -61,7 +62,7 @@ class TestRstDirectives(unittest.TestCase):
         self.assertEqual(True, options['noviewbox'])
         self.assertEqual(True, options['inline_svg'])
 
-    @stderr_wrapper
+    @capture_stderr
     def test_base_noargs(self):
         text = ".. blockdiag::"
         doctree = publish_doctree(text)
@@ -77,7 +78,7 @@ class TestRstDirectives(unittest.TestCase):
         self.assertEqual(None, doctree[0]['alt'])
         self.assertEqual({}, doctree[0]['options'])
 
-    @stderr_wrapper
+    @capture_stderr
     def test_base_with_emptyblock(self):
         text = ".. blockdiag::\n\n   \n"
         doctree = publish_doctree(text)
@@ -96,13 +97,13 @@ class TestRstDirectives(unittest.TestCase):
         self.assertEqual(None, doctree[0]['alt'])
         self.assertEqual({}, doctree[0]['options'])
 
-    @stderr_wrapper
+    @capture_stderr
     def test_base_with_filename_not_exists(self):
         text = ".. blockdiag:: unknown.diag"
         doctree = publish_doctree(text)
         self.assertEqual(nodes.system_message, type(doctree[0]))
 
-    @stderr_wrapper
+    @capture_stderr
     def test_base_with_block_and_filename(self):
         text = ".. blockdiag:: unknown.diag\n\n   { A -> B }"
         doctree = publish_doctree(text)
